==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEAuthorizationFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEAuthorizationFluent<A extends ACMEAuthorizationFluent<A>> extends BaseFluent<A>{
  public ACMEAuthorizationFluent() {
  }
  public ACMEAuthorizationFluent(ACMEAuthorization instance) {
    instance = (instance != null ? instance : new ACMEAuthorization());

    if (instance != null) {
      this.withChallenges(instance.getChallenges());
      this.withIdentifier(instance.getIdentifier());
      this.withInitialState(instance.getInitialState());
      this.withUrl(instance.getUrl());
      this.withWildcard(instance.getWildcard());
      this.withChallenges(instance.getChallenges());
      this.withIdentifier(instance.getIdentifier());
      this.withInitialState(instance.getInitialState());
      this.withUrl(instance.getUrl());
      this.withWildcard(instance.getWildcard());
    }
  }
  private ArrayList<ACMEChallengeBuilder> challenges = new ArrayList<ACMEChallengeBuilder>();
  private String identifier;
  private String initialState;
  private String url;
  private Boolean wildcard;
  public A addToChallenges(int index,ACMEChallenge item) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);
    if (index < 0 || index >= challenges.size()) { _visitables.get("challenges").add(builder); challenges.add(builder); } else { _visitables.get("challenges").add(index, builder); challenges.add(index, builder);}
    return (A)this;
  }
  public A setToChallenges(int index,ACMEChallenge item) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);
    if (index < 0 || index >= challenges.size()) { _visitables.get("challenges").add(builder); challenges.add(builder); } else { _visitables.get("challenges").set(index, builder); challenges.set(index, builder);}
    return (A)this;
  }
  public A addToChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").add(builder);this.challenges.add(builder);} return (A)this;
  }
  public A addAllToChallenges(Collection<ACMEChallenge> items) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").add(builder);this.challenges.add(builder);} return (A)this;
  }
  public A removeFromChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items) {
    if (this.challenges == null) return (A)this;
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").remove(builder); this.challenges.remove(builder);} return (A)this;
  }
  public A removeAllFromChallenges(Collection<ACMEChallenge> items) {
    if (this.challenges == null) return (A)this;
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").remove(builder); this.challenges.remove(builder);} return (A)this;
  }
  public A removeMatchingFromChallenges(Predicate<ACMEChallengeBuilder> predicate) {
    if (challenges == null) return (A) this;
    final Iterator<ACMEChallengeBuilder> each = challenges.iterator();
    final List visitables = _visitables.get("challenges");
    while (each.hasNext()) {
      ACMEChallengeBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<ACMEChallenge> buildChallenges() {
    return challenges != null ? build(challenges) : null;
  }
  public ACMEChallenge buildChallenge(int index) {
    return this.challenges.get(index).build();
  }
  public ACMEChallenge buildFirstChallenge() {
    return this.challenges.get(0).build();
  }
  public ACMEChallenge buildLastChallenge() {
    return this.challenges.get(challenges.size() - 1).build();
  }
  public ACMEChallenge buildMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate) {
    for (ACMEChallengeBuilder item: challenges) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate) {
    for (ACMEChallengeBuilder item: challenges) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withChallenges(List<ACMEChallenge> challenges) {
    if (this.challenges != null) { _visitables.get("challenges").clear();}
    if (challenges != null) {this.challenges = new ArrayList(); for (ACMEChallenge item : challenges){this.addToChallenges(item);}} else { this.challenges = null;} return (A) this;
  }
  public A withChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... challenges) {
    if (this.challenges != null) {this.challenges.clear(); _visitables.remove("challenges"); }
    if (challenges != null) {for (ACMEChallenge item :challenges){ this.addToChallenges(item);}} return (A) this;
  }
  public boolean hasChallenges() {
    return challenges != null && !challenges.isEmpty();
  }
  public A addNewChallenge(String token,String type,String url) {
    return (A)addToChallenges(new ACMEChallenge(token, type, url));
  }
  public ChallengesNested<A> addNewChallenge() {
    return new ChallengesNested(-1, null);
  }
  public ChallengesNested<A> addNewChallengeLike(ACMEChallenge item) {
    return new ChallengesNested(-1, item);
  }
  public ChallengesNested<A> setNewChallengeLike(int index,ACMEChallenge item) {
    return new ChallengesNested(index, item);
  }
  public ChallengesNested<A> editChallenge(int index) {
    if (challenges.size() <= index) throw new RuntimeException("Can't edit challenges. Index exceeds size.");
    return setNewChallengeLike(index, buildChallenge(index));
  }
  public ChallengesNested<A> editFirstChallenge() {
    if (challenges.size() == 0) throw new RuntimeException("Can't edit first challenges. The list is empty.");
    return setNewChallengeLike(0, buildChallenge(0));
  }
  public ChallengesNested<A> editLastChallenge() {
    int index = challenges.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last challenges. The list is empty.");
    return setNewChallengeLike(index, buildChallenge(index));
  }
  public ChallengesNested<A> editMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate) {
    int index = -1;
    for (int i=0;i<challenges.size();i++) { 
    if (predicate.test(challenges.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching challenges. No match found.");
    return setNewChallengeLike(index, buildChallenge(index));
  }
  public String getIdentifier() {
    return this.identifier;
  }
  public A withIdentifier(String identifier) {
    this.identifier=identifier; return (A) this;
  }
  public boolean hasIdentifier() {
    return this.identifier != null;
  }
  public String getInitialState() {
    return this.initialState;
  }
  public A withInitialState(String initialState) {
    this.initialState=initialState; return (A) this;
  }
  public boolean hasInitialState() {
    return this.initialState != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public boolean hasUrl() {
    return this.url != null;
  }
  public Boolean getWildcard() {
    return this.wildcard;
  }
  public A withWildcard(Boolean wildcard) {
    this.wildcard=wildcard; return (A) this;
  }
  public boolean hasWildcard() {
    return this.wildcard != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEAuthorizationFluent that = (ACMEAuthorizationFluent) o;
    if (!java.util.Objects.equals(challenges, that.challenges)) return false;

    if (!java.util.Objects.equals(identifier, that.identifier)) return false;

    if (!java.util.Objects.equals(initialState, that.initialState)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    if (!java.util.Objects.equals(wildcard, that.wildcard)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(challenges,  identifier,  initialState,  url,  wildcard,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (challenges != null && !challenges.isEmpty()) { sb.append("challenges:"); sb.append(challenges + ","); }
    if (identifier != null) { sb.append("identifier:"); sb.append(identifier + ","); }
    if (initialState != null) { sb.append("initialState:"); sb.append(initialState + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (wildcard != null) { sb.append("wildcard:"); sb.append(wildcard); }
    sb.append("}");
    return sb.toString();
  }
  public A withWildcard() {
    return withWildcard(true);
  }
  public class ChallengesNested<N> extends ACMEChallengeFluent<ChallengesNested<N>> implements Nested<N>{
    ChallengesNested(int index,ACMEChallenge item) {
      this.index = index;
      this.builder = new ACMEChallengeBuilder(this, item);
    }
    ACMEChallengeBuilder builder;
    int index;
    public N and() {
      return (N) ACMEAuthorizationFluent.this.setToChallenges(index,builder.build());
    }
    public N endChallenge() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEAuthorizationFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEAuthorizationFluent<A extends ACMEAuthorizationFluent<A>> extends BaseFluent<A>{
  public ACMEAuthorizationFluent() {
  }
  
  public ACMEAuthorizationFluent(ACMEAuthorization instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ACMEChallengeBuilder> challenges = new ArrayList<ACMEChallengeBuilder>();
  private String identifier;
  private String initialState;
  private String url;
  private Boolean wildcard;
  
  protected void copyInstance(ACMEAuthorization instance) {
    instance = (instance != null ? instance : new ACMEAuthorization());
  
    if (instance != null) {
        this.withChallenges(instance.getChallenges());
        this.withIdentifier(instance.getIdentifier());
        this.withInitialState(instance.getInitialState());
        this.withUrl(instance.getUrl());
        this.withWildcard(instance.getWildcard());
        this.withChallenges(instance.getChallenges());
        this.withIdentifier(instance.getIdentifier());
        this.withInitialState(instance.getInitialState());
        this.withUrl(instance.getUrl());
        this.withWildcard(instance.getWildcard());
      }
  }
  
  public A addToChallenges(int index,ACMEChallenge item) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);
    if (index < 0 || index >= challenges.size()) { _visitables.get("challenges").add(builder); challenges.add(builder); } else { _visitables.get("challenges").add(index, builder); challenges.add(index, builder);}
    return (A)this;
  }
  
  public A setToChallenges(int index,ACMEChallenge item) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);
    if (index < 0 || index >= challenges.size()) { _visitables.get("challenges").add(builder); challenges.add(builder); } else { _visitables.get("challenges").set(index, builder); challenges.set(index, builder);}
    return (A)this;
  }
  
  public A addToChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").add(builder);this.challenges.add(builder);} return (A)this;
  }
  
  public A addAllToChallenges(Collection<ACMEChallenge> items) {
    if (this.challenges == null) {this.challenges = new ArrayList<ACMEChallengeBuilder>();}
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").add(builder);this.challenges.add(builder);} return (A)this;
  }
  
  public A removeFromChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... items) {
    if (this.challenges == null) return (A)this;
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").remove(builder); this.challenges.remove(builder);} return (A)this;
  }
  
  public A removeAllFromChallenges(Collection<ACMEChallenge> items) {
    if (this.challenges == null) return (A)this;
    for (ACMEChallenge item : items) {ACMEChallengeBuilder builder = new ACMEChallengeBuilder(item);_visitables.get("challenges").remove(builder); this.challenges.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromChallenges(Predicate<ACMEChallengeBuilder> predicate) {
    if (challenges == null) return (A) this;
    final Iterator<ACMEChallengeBuilder> each = challenges.iterator();
    final List visitables = _visitables.get("challenges");
    while (each.hasNext()) {
      ACMEChallengeBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ACMEChallenge> buildChallenges() {
    return challenges != null ? build(challenges) : null;
  }
  
  public ACMEChallenge buildChallenge(int index) {
    return this.challenges.get(index).build();
  }
  
  public ACMEChallenge buildFirstChallenge() {
    return this.challenges.get(0).build();
  }
  
  public ACMEChallenge buildLastChallenge() {
    return this.challenges.get(challenges.size() - 1).build();
  }
  
  public ACMEChallenge buildMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate) {
    for (ACMEChallengeBuilder item: challenges) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate) {
    for (ACMEChallengeBuilder item: challenges) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withChallenges(List<ACMEChallenge> challenges) {
    if (this.challenges != null) { _visitables.get("challenges").clear();}
    if (challenges != null) {this.challenges = new ArrayList(); for (ACMEChallenge item : challenges){this.addToChallenges(item);}} else { this.challenges = null;} return (A) this;
  }
  
  public A withChallenges(io.fabric8.certmanager.api.model.acme.v1alpha3.ACMEChallenge... challenges) {
    if (this.challenges != null) {this.challenges.clear(); _visitables.remove("challenges"); }
    if (challenges != null) {for (ACMEChallenge item :challenges){ this.addToChallenges(item);}} return (A) this;
  }
  
  public boolean hasChallenges() {
    return challenges != null && !challenges.isEmpty();
  }
  
  public A addNewChallenge(String token,String type,String url) {
    return (A)addToChallenges(new ACMEChallenge(token, type, url));
  }
  
  public ChallengesNested<A> addNewChallenge() {
    return new ChallengesNested(-1, null);
  }
  
  public ChallengesNested<A> addNewChallengeLike(ACMEChallenge item) {
    return new ChallengesNested(-1, item);
  }
  
  public ChallengesNested<A> setNewChallengeLike(int index,ACMEChallenge item) {
    return new ChallengesNested(index, item);
  }
  
  public ChallengesNested<A> editChallenge(int index) {
    if (challenges.size() <= index) throw new RuntimeException("Can't edit challenges. Index exceeds size.");
    return setNewChallengeLike(index, buildChallenge(index));
  }
  
  public ChallengesNested<A> editFirstChallenge() {
    if (challenges.size() == 0) throw new RuntimeException("Can't edit first challenges. The list is empty.");
    return setNewChallengeLike(0, buildChallenge(0));
  }
  
  public ChallengesNested<A> editLastChallenge() {
    int index = challenges.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last challenges. The list is empty.");
    return setNewChallengeLike(index, buildChallenge(index));
  }
  
  public ChallengesNested<A> editMatchingChallenge(Predicate<ACMEChallengeBuilder> predicate) {
    int index = -1;
    for (int i=0;i<challenges.size();i++) { 
    if (predicate.test(challenges.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching challenges. No match found.");
    return setNewChallengeLike(index, buildChallenge(index));
  }
  
  public String getIdentifier() {
    return this.identifier;
  }
  
  public A withIdentifier(String identifier) {
    this.identifier=identifier; return (A) this;
  }
  
  public boolean hasIdentifier() {
    return this.identifier != null;
  }
  
  public String getInitialState() {
    return this.initialState;
  }
  
  public A withInitialState(String initialState) {
    this.initialState=initialState; return (A) this;
  }
  
  public boolean hasInitialState() {
    return this.initialState != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public Boolean getWildcard() {
    return this.wildcard;
  }
  
  public A withWildcard(Boolean wildcard) {
    this.wildcard=wildcard; return (A) this;
  }
  
  public boolean hasWildcard() {
    return this.wildcard != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEAuthorizationFluent that = (ACMEAuthorizationFluent) o;
    if (!java.util.Objects.equals(challenges, that.challenges)) return false;
  
    if (!java.util.Objects.equals(identifier, that.identifier)) return false;
  
    if (!java.util.Objects.equals(initialState, that.initialState)) return false;
  
    if (!java.util.Objects.equals(url, that.url)) return false;
  
    if (!java.util.Objects.equals(wildcard, that.wildcard)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(challenges,  identifier,  initialState,  url,  wildcard,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (challenges != null && !challenges.isEmpty()) { sb.append("challenges:"); sb.append(challenges + ","); }
    if (identifier != null) { sb.append("identifier:"); sb.append(identifier + ","); }
    if (initialState != null) { sb.append("initialState:"); sb.append(initialState + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (wildcard != null) { sb.append("wildcard:"); sb.append(wildcard); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withWildcard() {
    return withWildcard(true);
  }
  public class ChallengesNested<N> extends ACMEChallengeFluent<ChallengesNested<N>> implements Nested<N>{
    ChallengesNested(int index,ACMEChallenge item) {
      this.index = index;
      this.builder = new ACMEChallengeBuilder(this, item);
    }
    ACMEChallengeBuilder builder;
    int index;
    
    public N and() {
      return (N) ACMEAuthorizationFluent.this.setToChallenges(index,builder.build());
    }
    
    public N endChallenge() {
      return and();
    }
    
  
  }

}
